@@ -231,13 +231,15 @@ class SemanticScholar:
         with open(fname, "w") as f:
             json.dump(data, f)
         print(f"Wrote file {fname}")
-        other_ids = [details["externalIds"].get(k, "") for k in self._id_keys]  # type: ignore
+        ext_ids = {self.id_types(k): v for k, v in details["externalIds"].items()}  # type: ignore
+        other_ids = [ext_ids.get(k, "") for k in self._id_keys]  # type: ignore
         for ind, key in enumerate(self._id_keys):
             if other_ids[ind]:
                 self._cache[key][other_ids[ind]] = paper_id
         existing = self._rev_cache.get(paper_id, None)
         if existing:
-            self._rev_cache[paper_id] = [x or y for x, y in zip(self._rev_cache[paper_id], other_ids)]
+            self._rev_cache[paper_id] = [x or y for x, y in
+                                         zip(self._rev_cache[paper_id], other_ids)]
         else:
             self._rev_cache[paper_id] = other_ids
             self.update_metadata(paper_id)
@@ -445,7 +447,7 @@ class SemanticScholar:
         else:
             itype = self.id_types(id_type)
             ssid = self._cache[itype].get(ID, "")
-            have_metadata = bool(ID)
+            have_metadata = bool(ssid)
         return self.apply_limits(self.fetch_from_cache_or_service(
             have_metadata, ssid or ids[id_type], force, False))
 
@@ -475,8 +477,8 @@ class SemanticScholar:
             limit = self._config["citations"]["limit"]
             _data["citations"] = _data["citations"][:limit]
         if "references" in data:
-            limit = self._config["citations"]["limit"]
-            _data["references"] = _data["citations"][:limit]
+            limit = self._config["references"]["limit"]
+            _data["references"] = _data["references"][:limit]
         return _data
 
     # TODO: Do I need two details functions?
