@@ -70,8 +70,8 @@ class RefMan:
     def __init__(self, host: str, port: int, proxy_port: int, proxy_everything: bool,
                  proxy_everything_port: int, data_dir: Path, local_pdfs_dir: Path,
                  remote_pdfs_dir: str, remote_links_cache: Path,
-                 config_dir: Path, batch_size: int,
-                 chrome_debugger_path: str, verbosity: str, threaded: bool):
+                 config_dir: Path, batch_size: int, chrome_debugger_path: str,
+                 debug: bool, verbosity: str, threaded: bool):
         self.host = "127.0.0.1"
         self.port = port
         self.batch_size = batch_size
@@ -88,6 +88,7 @@ class RefMan:
             os.makedirs(self.config_dir)
         self.config_file: Optional[Path] = self.config_dir.joinpath("config.json")
         self.config_file = self.config_file if self.config_file.exists() else None
+        self.debug = debug
         self.verbosity = verbosity
         self.threaded = threaded
 
@@ -622,7 +623,6 @@ class RefMan:
                 self.logd("Shutting down cache helper.")
                 self.pdf_cache_helper.shutdown()
             func = request.environ.get('werkzeug.server.shutdown')
-            print(f"PROC {self.proc._popen}")
             if func:
                 func()
             elif hasattr(self, "proc"):
@@ -639,7 +639,13 @@ class RefMan:
 
     def run(self):
         "Run the server"
-        self.proc = Process(target=serving.run_simple,
-                            args=(self.host, self.port, app),
-                            kwargs={"threaded": self.threaded})
-        self.proc.start()
+        if self.debug:
+            self.logd(f"Started Ref Man Service version {__version__} in debug mode")
+            serving.run_simple(self.host, self.port, app, self.threaded)
+            self.proc = None
+        else:
+            self.logd(f"Started Ref Man Service version {__version__}")
+            self.proc = Process(target=serving.run_simple,
+                                args=(self.host, self.port, app),
+                                kwargs={"threaded": self.threaded})
+            self.proc.start()
